<?php
namespace App\Modules\Usertype\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\Validator;

use App\Http\Requests;

use Illuminate\Validation\ValidationException;

use App\Modules\Usertype\Models\Usertype;

use App\Modules\Usertype\Models\RoleHasPermissions;

use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;

class UsertypeController extends Controller
{
     public function getRecords($id='', Request $request)
    {
        try{
            if($id > 0){
                
                return Usertype::find($id);

            }else if($request->has('query_string')){

                return Usertype::where('name', 'LIKE', '%' . $request->query_string . '%')->where('status', '=', '1')->paginate(10);

            }else if($request->has('activerecord')){
                return Usertype::where('status', '=', $request->activerecord)->orderBy('id', 'DESC')->get();
            }else{
                return Usertype::where('status', '!=', '0')->orderBy('id', 'DESC')->paginate(10);
            }
      }catch(\Illuminate\Database\QueryException $ex){
          
        $res['status'] = false;
        $res['message'] = $ex->getMessage();
        return response($res, 500);

      } 
    }


    public function getRoleWisePermission($id){
        $role_array = array();
        $roles_list = Usertype::find($id)->RolesOfPermissions;

        foreach($roles_list as $list){

            array_push($role_array, $list->id);
        }
        return $role_array;
        
    }

    public function create(Request $request)
    {
        //return $request;
        $id = 0;
         if($request->id > 0 ){
            $id = $request->id;
         }
        //creating a validator
        $validator = Validator::make($request->all(), [
                    
                    'name' => [
                        'required',
                        Rule::unique('user_types')->where(function ($query) use($id) {
                            $query->where('status','!=','0')->where('id','!=',$id);
                        })
                    ],
            'role_status' => 'required'
        ]);

        //if validation fails
        if ($validator->fails()) {
            return array(
                'error' => true,
                'message' => $validator->errors()
            );
        }
    try{
            //creating a new role
            $role = new Usertype();
            $role_permission = new RoleHasPermissions();
            //adding values to the userType table
            $role->name = $request->name;
            $role->description = $request->role_description;
            $role->status = $request->role_status;
            //return $request->permissions;
            //saving the role to database
            if($request->id > 0){
                try{
                $modification_date =  Carbon::now('Asia/Kolkata');

                if($request->id> 0 && $request->permissions> 0){

                    $role_permission->where('role_id', $request->id)->delete();

                    foreach($request->permissions as $permission){
                        $role_permission->role_id =  $request->id;
                        $role_permission->permission_id = $permission;
                        RoleHasPermissions::create(['role_id' => $role_permission->role_id, 'permission_id'=>$role_permission->permission_id]);
                    }

                }
                $item = $role->findOrFail($request->id);
                if($item){
                    
                    $role->where('id', $request->id)->update(['name'=>$role->name,'description'=>$role->description,'status'=>$role->status, 'modification_date'=>$modification_date]);

                    $res['error'] = false;
                    $res['actions'] = 'update';
                    return response($res, 200);
                }
             }catch(\Illuminate\Database\QueryException $ex){

                $res['status'] = false;
                $res['message'] = $ex->getMessage();
                return response($res, 500);

             } 
            }else{
                if (empty($request->permissions)){
                    $role->save();
                    }else{
                    $role->save();
                    $role_id =  $role->id;
                    if($role_id && $request->permissions> 0){
                            foreach($request->permissions as $permission){
                                $role_permission->role_id = $role_id;
                                $role_permission->permission_id = $permission;
                                RoleHasPermissions::create(['role_id' => $role_id, 'permission_id'=>$permission]);
                                
                            }
                    }
                }
            $res['error'] = false;
            $res['actions'] = 'add';
            return response($res, 200);

          }
        }catch(\Illuminate\Database\QueryException $ex){

            $res['status'] = false;
            $res['message'] = $ex->getMessage();
            return response($res, 500);
        }
    }

    public function delete(Request $request)
    {
        $role = Usertype::findOrFail($request->role_id);
        try{
            if($role){
            $role->where('id', $request->role_id)->update(['status'=>'0']);
                $res['error'] = false;
                return response($res, 200);
            }else{
            $res['error'] = true;
            return response($res, 401);
            }
       }catch(\Illuminate\Database\QueryException $ex){

        $res['status'] = false;
        $res['message'] = $ex->getMessage();
        return response($res, 500);
      }
    }

    public function getMultipleRolePermission(Request $request){

        $role_array = array();
        //return $request->roles;
        if(!empty($request->roles) && count($request->roles) > 0){
            $roles_list = RoleHasPermissions::select('permission_id')->whereIn('role_id', $request->roles)->distinct()->get();
        
            foreach($roles_list as $list){
    
                array_push($role_array, $list->permission_id);
            }
        }

        return $role_array;
    }
}
